Stan Math Library: stan/math/fwd/core/std_numeric_limits.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

std_numeric_limits.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_CORE_STD_NUMERIC_LIMITS_HPP
2 #define STAN_MATH_FWD_CORE_STD_NUMERIC_LIMITS_HPP
3
4 #include <stan/math/fwd/core/fvar.hpp>
5 #include <limits>
6
7 namespace std {
8
9 template <typename T>
10
11 struct numeric_limits<stan::math::fvar<T> > {
12 static const bool is_specialized = true;
13 static stan::math::fvar<T> min() { return numeric_limits<double>::min(); }
14 static stan::math::fvar<T> max() { return numeric_limits<double>::max(); }
15 static const int digits = numeric_limits<double>::digits;
16 static const int digits10 = numeric_limits<double>::digits10;
17 static const bool is_signed = numeric_limits<double>::is_signed;
18 static const bool is_integer = numeric_limits<double>::is_integer;
19 static const bool is_exact = numeric_limits<double>::is_exact;
20 static const int radix = numeric_limits<double>::radix;
21 static stan::math::fvar<T> epsilon() {
22 return numeric_limits<double>::epsilon(); }
23 static stan::math::fvar<T> round_error() {
24 return numeric_limits<double>::round_error(); }
25
26 static const int min_exponent = numeric_limits<double>::min_exponent;
27 static const int min_exponent10 = numeric_limits<double>::min_exponent10;
28 static const int max_exponent = numeric_limits<double>::max_exponent;
29 static const int max_exponent10 = numeric_limits<double>::max_exponent10;
30
31 static const bool has_infinity = numeric_limits<double>::has_infinity;
32 static const bool has_quiet_NaN = numeric_limits<double>::has_quiet_NaN;
33 static const bool has_signaling_NaN =
34 numeric_limits<double>::has_signaling_NaN;
35 static const float_denorm_style has_denorm =
36 numeric_limits<double>::has_denorm;
37 static const bool has_denorm_loss = numeric_limits<double>::has_denorm_loss;
38 static stan::math::fvar<T> infinity() {
39 return numeric_limits<double>::infinity(); }
40 static stan::math::fvar<T> quiet_NaN() {
41 return numeric_limits<double>::quiet_NaN(); }
42 static stan::math::fvar<T> signaling_NaN() {
43 return numeric_limits<double>::signaling_NaN(); }
44 static stan::math::fvar<T> denorm_min() {
45 return numeric_limits<double>::denorm_min(); }
46
47 static const bool is_iec559 = numeric_limits<double>::is_iec559;
48 static const bool is_bounded = numeric_limits<double>::is_bounded;
49 static const bool is_modulo = numeric_limits<double>::is_modulo;
50
51 static const bool traps = numeric_limits<double>::traps;
52 static const bool tinyness_before = numeric_limits<double>::tinyness_before;
53 static const float_round_style round_style =
54 numeric_limits<double>::round_style;
55 };
56 }
57 #endif
std::numeric_limits< stan::math::fvar< T > >::max
static stan::math::fvar< T > max()
Definition: std_numeric_limits.hpp:14
std::numeric_limits< stan::math::fvar< T > >::epsilon
static stan::math::fvar< T > epsilon()
Definition: std_numeric_limits.hpp:21
std::numeric_limits< stan::math::fvar< T > >::infinity
static stan::math::fvar< T > infinity()
Definition: std_numeric_limits.hpp:38
stan::math::min
int min(const std::vector< int > &x)
Returns the minimum coefficient in the specified column vector.
Definition: min.hpp:20
stan
Definition: log_sum_exp.hpp:8
std
Definition: std_numeric_limits.hpp:7
std::numeric_limits< stan::math::fvar< T > >::denorm_min
static stan::math::fvar< T > denorm_min()
Definition: std_numeric_limits.hpp:44
std::numeric_limits< stan::math::fvar< T > >::min
static stan::math::fvar< T > min()
Definition: std_numeric_limits.hpp:13
fvar.hpp
stan::math::max
int max(const std::vector< int > &x)
Returns the maximum coefficient in the specified column vector.
Definition: max.hpp:21
std::numeric_limits< stan::math::fvar< T > >::signaling_NaN
static stan::math::fvar< T > signaling_NaN()
Definition: std_numeric_limits.hpp:42
std::numeric_limits< stan::math::fvar< T > >::round_error
static stan::math::fvar< T > round_error()
Definition: std_numeric_limits.hpp:23
std::numeric_limits< stan::math::fvar< T > >::quiet_NaN
static stan::math::fvar< T > quiet_NaN()
Definition: std_numeric_limits.hpp:40
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.